@@ -303,6 +303,47 @@ void db_connect(void)
 	sqlite3_free(create_sql);
 	sqlite3_free_table(sqlresult);
       }
+
+      /* Check if the database contains the pricepertrip column (0.90.4 and before did not) */
+      rc = sqlite3_get_table(db, "SELECT pricepertrip FROM record LIMIT 1",&sqlresult, &sqlrows, &sqlcolumns, NULL);
+      sqlite3_free_table(sqlresult);
+      if (rc != SQLITE_OK ) { /* create new column if not found */
+	PDEBUG("Creating new pricepertrip column to table record\n");
+	create_sql = sqlite3_mprintf(
+				     "ALTER TABLE record "
+				     "ADD COLUMN pricepertrip NUMBER;"
+				     );
+	if (SQLITE_OK != sqlite3_exec(db, create_sql, NULL, NULL, &zErrMsg) &&
+	    SQLITE_OK != sqlite3_get_table(db, "SELECT pricepertrip FROM record LIMIT 1",&sqlresult, &sqlrows, &sqlcolumns, NULL)) {
+	  PDEBUG("Failed to add pricepertrip column to database\n");
+	  PDEBUG("%s\n",sqlite3_errmsg(db));
+	  sqlite3_close(db);
+	  db = NULL;
+	  sqlite3_free(create_sql);
+	  sqlite3_free_table(sqlresult);
+	}
+	else {
+	  sqlite3_free(create_sql);
+	  sqlite3_free_table(sqlresult);
+
+	  PDEBUG("Recalculating the pricepertrip columns\n");
+
+	  create_sql = sqlite3_mprintf(
+				       "UPDATE record "
+				       "SET pricepertrip=price/trip "
+				       "WHERE trip NOT in (0);"
+				       );
+	  if (SQLITE_OK != sqlite3_exec(db, create_sql, NULL, NULL, &zErrMsg)) {
+	    PDEBUG("Failed to calculate column pricepertrip\n");
+	    PDEBUG("%s\n",sqlite3_errmsg(db));
+
+	  }
+	  sqlite3_free(create_sql);
+	  sqlite3_free_table(sqlresult);
+
+	}
+      }
+
     }
 
     if (db) {
@@ -372,13 +413,13 @@ void db_connect(void)
 
       /* prepare sql query for obtaining one record */
       rc = sqlite3_prepare_v2(db, 
-"SELECT day,km,trip,fill,price,service,oil,tires,notes,consum,id "
+"SELECT day,km,trip,fill,price,pricepertrip,service,oil,tires,notes,consum,id "
 "FROM record WHERE id=?;", -1, &ppStmtOneRecord, NULL);
 
       /* prepare sql query for obtaining all the records */
       rc = sqlite3_prepare_v2(db, 
 "SELECT day,km,trip,fill,consum,price,"
-"priceperlitre,service,oil,tires,notes,"
+"priceperlitre,pricepertrip,service,oil,tires,notes,"
 "id FROM record WHERE carid=? ORDER BY km;", -1, &ppStmtRecords, NULL);
 
       /* prepare sql query for obtaining all the records (more fields
@@ -393,25 +434,25 @@ void db_connect(void)
       /* prepare sql query for adding a record */
       rc = sqlite3_prepare_v2(db, 
 "INSERT "
-"INTO record(carid,driverid,day,km,trip,fill,consum,price,priceperlitre,service,oil,tires,notes) "
-"VALUES(?,?,?,?,?,?,?,?,?,?,?,?,?);", -1, &ppStmtAddRecord, NULL);
+"INTO record(carid,driverid,day,km,trip,fill,consum,price,priceperlitre,pricepertrip,service,oil,tires,notes) "
+"VALUES(?,?,?,?,?,?,?,?,?,?,?,?,?,?);", -1, &ppStmtAddRecord, NULL);
 
       /* prepare sql query for calculating the full fill (fill and total km) */
       rc = sqlite3_prepare_v2(db, 
 "SELECT "
-"km,trip,fill,consum,id FROM record WHERE carid=? AND km>? AND fill>0 AND consum>0 ORDER BY km LIMIT 1;", 
+"km,trip,fill,consum,price,id FROM record WHERE carid=? AND km>? AND fill>0 AND consum>0 ORDER BY km LIMIT 1;", 
 			      -1, &ppStmtNextFull, NULL);
 
       /* prepare sql query for calculating the full fill (fill and total km) */
       rc = sqlite3_prepare_v2(db, 
 "SELECT "
-"km,trip,fill,consum,id FROM record WHERE carid=? AND km<? AND fill>0 ORDER BY km DESC;", 
+"km,trip,fill,consum,price,id FROM record WHERE carid=? AND km<? AND fill>0 ORDER BY km DESC;", 
 			      -1, &ppStmtPrevFull, NULL);
 
       /* prepare sql query for changing a record */
       rc = sqlite3_prepare_v2(db, 
 "UPDATE record "
-"SET day=?, km=?, trip=?, fill=?, consum=?, price=?, priceperlitre=?, service=?, oil=?, tires=?, notes=? WHERE id=?;", -1, &ppStmtUpdateRecord, NULL);
+"SET day=?, km=?, trip=?, fill=?, consum=?, price=?, priceperlitre=?, pricepertrip=?, service=?, oil=?, tires=?, notes=? WHERE id=?;", -1, &ppStmtUpdateRecord, NULL);
 
       /* Prepare sql query for obtaining the years that contain data */
       rc = sqlite3_prepare_v2(db,
@@ -806,7 +847,7 @@ float db_get_last_refill(double newkm)
  return ret;
 }
 
-void db_find_prev_full(double km, double *fullfill, double *fullkm)
+void db_find_prev_full(double km, double *fullfill, double *fullkm, double *fullprice)
 {
 /*   char **sqlresult; */
 /*   char *sqlquery; */
@@ -816,9 +857,11 @@ void db_find_prev_full(double km, double *fullfill, double *fullkm)
   double fill;
   double trip;
   double consum;
+  double price;
   
   *fullfill=0.0;
   *fullkm=0.0;
+  *fullprice=0.0;
   if (db) {
     if (!(SQLITE_OK != sqlite3_bind_int(ppStmtPrevFull, 1, currentcar) /* carid */
 	  || SQLITE_OK != sqlite3_bind_double(ppStmtPrevFull, 2, km)) ) {
@@ -826,11 +869,13 @@ void db_find_prev_full(double km, double *fullfill, double *fullkm)
 	    trip=sqlite3_column_double(ppStmtPrevFull,1);
 	    fill=sqlite3_column_double(ppStmtPrevFull,2);
 	    consum=sqlite3_column_double(ppStmtPrevFull,3);
+	    price=sqlite3_column_double(ppStmtPrevFull,4);
 	    if (abs(consum)>1e-3) /* Full fill found*/
 	      break;
 	    else {
 	      *fullfill += fill;
 	      *fullkm += trip;
+	      *fullprice += price;
 	    }
 	
 	  }
@@ -839,11 +884,12 @@ void db_find_prev_full(double km, double *fullfill, double *fullkm)
   }
 }
 
-sqlite_int64 db_find_next_full(double km, double *fullfill, double *fullkm)
+sqlite_int64 db_find_next_full(double km, double *fullfill, double *fullkm, double *fullprice)
 {
   sqlite_int64 id;
   double fill;
   double trip;
+  double price;
 
   id=-1;
   if (db) {
@@ -853,11 +899,13 @@ sqlite_int64 db_find_next_full(double km, double *fullfill, double *fullkm)
 	km = sqlite3_column_double(ppStmtNextFull,0);
 	trip = sqlite3_column_double(ppStmtNextFull,1);
 	fill = sqlite3_column_double(ppStmtNextFull,2);
-	id = sqlite3_column_int64(ppStmtNextFull,4);
+	price = sqlite3_column_double(ppStmtNextFull,4);
+	id = sqlite3_column_int64(ppStmtNextFull,5);
 	sqlite3_reset(ppStmtNextFull);
-	db_find_prev_full(km,fullfill,fullkm);
+	db_find_prev_full(km,fullfill,fullkm,fullprice);
 	*fullfill += fill;
 	*fullkm += trip;
+	*fullprice += price;
       }
       else
 	sqlite3_reset(ppStmtNextFull);
@@ -2161,6 +2209,7 @@ sqlite_int64 db_add_record(char * date,
 			   double consum,
 			   double price,
 			   double priceperlitre,
+			   double pricepertrip,
 			   double service,
 			   double oil,
 			   double tires,
@@ -2190,12 +2239,14 @@ sqlite_int64 db_add_record(char * date,
 	    || SQLITE_OK != sqlite3_bind_double(ppStmtAddRecord, 9,
 						priceperlitre)
 	    || SQLITE_OK != sqlite3_bind_double(ppStmtAddRecord, 10,
-						service)
+						pricepertrip)
 	    || SQLITE_OK != sqlite3_bind_double(ppStmtAddRecord, 11,
-						oil)
+						service)
 	    || SQLITE_OK != sqlite3_bind_double(ppStmtAddRecord, 12,
+						oil)
+	    || SQLITE_OK != sqlite3_bind_double(ppStmtAddRecord, 13,
 						tires)
-	    || SQLITE_OK != sqlite3_bind_text(ppStmtAddRecord, 13, 
+	    || SQLITE_OK != sqlite3_bind_text(ppStmtAddRecord, 14,
 					      notes,
 					      -1, SQLITE_STATIC)
 	    || SQLITE_DONE != sqlite3_step(ppStmtAddRecord)) {
@@ -2217,6 +2268,7 @@ sqlite_int64 db_update_record(sqlite_int64 id,
 			      double consum,
 			      double price,
 			      double priceperlitre,
+			      double pricepertrip,
 			      double service,
 			      double oil,
 			      double tires,
@@ -2252,7 +2304,7 @@ sqlite_int64 db_update_record(sqlite_int64 id,
 						    : fill) )
 	      || ( SQLITE_OK != sqlite3_bind_double(ppStmtUpdateRecord, 5,
 						    (consum < 0.0) ?
-						    sqlite3_column_double(ppStmtOneRecord,9)
+						    sqlite3_column_double(ppStmtOneRecord,10)
 						    : consum) )
 	      || ( SQLITE_OK != sqlite3_bind_double(ppStmtUpdateRecord, 6,
 						    (price < 0.0) ?
@@ -2264,23 +2316,27 @@ sqlite_int64 db_update_record(sqlite_int64 id,
 						    sqlite3_column_double(ppStmtOneRecord,3)
 						    : priceperlitre) )
 	      || (  SQLITE_OK != sqlite3_bind_double(ppStmtUpdateRecord, 8,
-						     (service < 0.0) ?
+						     (pricepertrip < 0.0) ?
 						     sqlite3_column_double(ppStmtOneRecord,5)
+						     : pricepertrip) )
+	      || (  SQLITE_OK != sqlite3_bind_double(ppStmtUpdateRecord, 9,
+						     (service < 0.0) ?
+						     sqlite3_column_double(ppStmtOneRecord,6)
 						     : service) )
-	      || ( SQLITE_OK != sqlite3_bind_double(ppStmtUpdateRecord, 9,
-						    (oil < 0.0) ?
-						    sqlite3_column_double(ppStmtOneRecord,6)
-						    : oil) )
 	      || ( SQLITE_OK != sqlite3_bind_double(ppStmtUpdateRecord, 10,
-						    (tires < 0.0) ?
+						    (oil < 0.0) ?
 						    sqlite3_column_double(ppStmtOneRecord,7)
+						    : oil) )
+	      || ( SQLITE_OK != sqlite3_bind_double(ppStmtUpdateRecord, 11,
+						    (tires < 0.0) ?
+						    sqlite3_column_double(ppStmtOneRecord,8)
 						    : tires) )
-	      || ( SQLITE_OK != sqlite3_bind_text(ppStmtUpdateRecord, 11,
+	      || ( SQLITE_OK != sqlite3_bind_text(ppStmtUpdateRecord, 12,
 						  (notes == NULL) ?
-						  sqlite3_column_text(ppStmtOneRecord,8) 
+						  sqlite3_column_text(ppStmtOneRecord,9) 
 						  : notes,
 						  -1, SQLITE_STATIC) )
-	      || SQLITE_OK != sqlite3_bind_int64(ppStmtUpdateRecord, 12,
+	      || SQLITE_OK != sqlite3_bind_int64(ppStmtUpdateRecord, 13,
 						 id)
 	      || SQLITE_DONE != sqlite3_step(ppStmtUpdateRecord)) {
 	    PDEBUG("Problem saving result");
