@@ -109,8 +109,8 @@ void db_close(void);
 int db_open(void);
 float db_get_last_km(void);
 float db_get_last_refill(double newkm);
-void db_find_prev_full(double km, double *fullfill, double *fullkm);
-sqlite_int64 db_find_next_full(double km, double *fullfill, double *fullkm);
+void db_find_prev_full(double km, double *fullfill, double *fullkm, double *fullprice);
+sqlite_int64 db_find_next_full(double km, double *fullfill, double *fullkm, double *fullprice);
 int db_get_monthly_data(int year, double **x, double **fill, double **trip, double **consum, double **priceperlitre);
 float db_get_totalkm(enum dbtimespan timespan);
 float db_get_totalfillkm(enum dbtimespan timespan);
@@ -157,6 +157,7 @@ sqlite_int64 db_add_record(char * date,
 			   double consum,
 			   double price,
 			   double priceperlitre,
+			   double pricepertrip,
 			   double service,
 			   double oil,
 			   double tires,
@@ -169,6 +170,7 @@ sqlite_int64 db_update_record(sqlite_int64 id,
 			      double consum,
 			      double price,
 			      double priceperlitre,
+			      double pricepertrip,
 			      double service,
 			      double oil,
 			      double tires,
