@@ -325,7 +325,7 @@ void newevent_response (GtkDialog *dialog, gint arg1, AppUIData *pui)
        notes = get_entry(pui->entryeventnotes);
 
        /* Save first to the record table */
-       recordid = db_add_record(date, km, 0.0, 0.0, 0.0, 0.0, 0.0,
+       recordid = db_add_record(date, km, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
 				service, oil, tires, notes->str);
        if (recordid<0) {
 	  PDEBUG("Problem saving result");
@@ -479,7 +479,7 @@ void editevent_response (GtkDialog *dialog, gint arg1, AppUIData *pui,
        notes = get_entry(pui->entryeventnotes);
 
        /* Edit first the record table */
-       if (db_update_record(recordid, date, km, -1.0, -1.0, -1.0, -1.0, -1.0,
+       if (db_update_record(recordid, date, km, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0,
 			    service, oil, tires, notes->str) != recordid) {
 	 PDEBUG("Problem saving result");
 	 free(date);
