@@ -108,12 +108,27 @@ create_csvpreview_view (csvlist *plist, gint rows, gint cols)
   return csvview;
 }
 
+gint get_active(GtkWidget *widget)
+{
+  gint retval;
+
+#if MAEMO_VERSION_MAJOR == 5
+  retval=hildon_touch_selector_get_active(HILDON_TOUCH_SELECTOR(widget), 0);
+#else
+  retval=gtk_combo_box_get_active(GTK_COMBO_BOX(widget));
+#endif
+
+  return retval;
+}
+
+
 void callback_startimport(GtkDialog *widget, gint arg1, AppUIData *pui)
 {
   gint i;
   gint fl;
   gboolean clocale;
   gint coldes[IMPORTCOLS];
+  GString *str;
   char *date;
   gdouble km;
   gdouble trip;
@@ -124,7 +139,7 @@ void callback_startimport(GtkDialog *widget, gint arg1, AppUIData *pui)
   gdouble oil;
   gdouble tires;
 
-  if (arg1==GTK_RESPONSE_ACCEPT) {
+  if (arg1==HILDON_WIZARD_DIALOG_FINISH) {
     ui_show_banner(_("Storing to database, please wait"));
 
     /* Update the UI */
@@ -143,13 +158,17 @@ void callback_startimport(GtkDialog *widget, gint arg1, AppUIData *pui)
 #endif
     }
 
-    clocale=(gtk_combo_box_get_active(GTK_COMBO_BOX(pui->localecombo)) == 1);
+/*     clocale=(gtk_combo_box_get_active(GTK_COMBO_BOX(pui->localecombo)) == 1); */
+    clocale=(get_active(pui->localecombo) == 1);
     if (clocale)
       setlocale(LC_NUMERIC, "C");
 
     for (i=fl;i<=plist.nodes;i++) {
 
-      date2sqlite(&date, gtk_entry_get_text(GTK_ENTRY(pui->dateformatentry)), (char *)(NONNULLOREMPTY((char *)(csvgetrowcol(&plist, i, coldes[0])))));
+      str=get_entry(pui->dateformatentry);
+      date2sqlite(&date, str->str, (char *)(NONNULLOREMPTY((char *)(csvgetrowcol(&plist, i, coldes[0])))));
+      g_string_free(str, TRUE);
+
       km = user2SIlength(atof(NONNULLORZERO((char *)(csvgetrowcol(&plist, i, coldes[1])))));
       trip = user2SIlength(atof(NONNULLORZERO((char *)(csvgetrowcol(&plist, i, coldes[2])))));
       fill = user2SIvolume(atof(NONNULLORZERO((char *)(csvgetrowcol(&plist, i, coldes[3])))));
@@ -232,13 +251,49 @@ GtkWidget *create_column_spinner(gint initval, gint maxval)
   return spinner;
 }
 
+#if MAEMO_VERSION_MAJOR == 5
+GtkWidget *create_locale_combo(GtkWidget *button)
+#else
+GtkWidget *create_locale_combo(void)
+#endif
+{
+  enum 
+  {
+    LOCALE_CURRENT=0,
+    LOCALE_C
+  };
+  GtkWidget *combo;
+  gchar *labels[] = {gettext_noop("current"),
+		     gettext_noop("C")
+  };
+
+#if MAEMO_VERSION_MAJOR == 5
+  combo = hildon_touch_selector_new_text ();
+  hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (combo), gettext(labels[LOCALE_CURRENT]));
+  hildon_touch_selector_append_text(HILDON_TOUCH_SELECTOR (combo), gettext(labels[LOCALE_C]));
+  hildon_touch_selector_set_active(HILDON_TOUCH_SELECTOR (combo), 0, 0);
+  hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (button),
+                                     HILDON_TOUCH_SELECTOR (combo));
+#else
+  combo = gtk_combo_box_new_text();
+  gtk_combo_box_append_text(GTK_COMBO_BOX (combo), gettext(labels[LOCALE_CURRENT]));
+  gtk_combo_box_append_text(GTK_COMBO_BOX (combo), gettext(labels[LOCALE_C]));
+  gtk_combo_box_set_active(GTK_COMBO_BOX (combo),0);
+#endif
+  return combo;
+}
+
+
 void callback_import( GtkAction * action, AppUIData *pui )
 {
+  gint confirm;
   gchar *filename = NULL;
   FILE *f;
   gint emptyrows;
   gint cols, rows;
   gint i;
+  gint row;
+  gint firstrow;
   csvlistnode *pl;
 #ifdef _GNU_SOURCE
   char *line;
@@ -262,7 +317,10 @@ void callback_import( GtkAction * action, AppUIData *pui )
   GtkWidget *csvview;
   GtkWidget *label;
   GtkWidget *combo;
-    
+#if MAEMO_VERSION_MAJOR == 5
+  GtkWidget *button;
+#endif
+
   filename = interface_file_chooser ("Open file",
 				     GTK_FILE_CHOOSER_ACTION_OPEN,
 				     "csv",
@@ -277,6 +335,8 @@ void callback_import( GtkAction * action, AppUIData *pui )
     cols=0;
     rows=0;
     emptyrows=0;
+    row=0;
+    firstrow=0;
     f=fopen (filename, "r");
 #ifdef _GNU_SOURCE
     while (getline(&line,&llen,f)!=-1 && emptyrows < 10)
@@ -287,6 +347,7 @@ void callback_import( GtkAction * action, AppUIData *pui )
 	/* Update the UI */
 	while (gtk_events_pending())
 	  gtk_main_iteration();
+	row++;
 	if (!g_utf8_validate(line, -1, NULL))
 	  convline=g_convert(line, -1, "UTF-8", "ISO-8859-15", NULL, NULL, NULL);
 	else
@@ -297,6 +358,10 @@ void callback_import( GtkAction * action, AppUIData *pui )
 	  emptyrows++;
 	else
 	  emptyrows=0;
+	if (firstrow==0 && atoi((char *)
+				((csvlist *)
+				 (csvlist *)plist.tail->data)->head->data) > 0)
+	  firstrow=row;
       }
 #ifdef _GNU_SOURCE
     free(line);
@@ -305,33 +370,25 @@ void callback_import( GtkAction * action, AppUIData *pui )
 
     fclose(f);
 
+    if (firstrow==0)
+      firstrow=1;
+
     for (i=emptyrows;i>0;i--) {
       pl = plist.tail;
       csvremoverow(&plist,pl);
     }
     rows=plist.nodes;
-
-    importwindow = gtk_dialog_new_with_buttons(_("Import"),
-					       GTK_WINDOW(pui->app->mainwindow),
-					       GTK_DIALOG_MODAL,
-					       GTK_STOCK_OK, 
-					       GTK_RESPONSE_ACCEPT,
-					       GTK_STOCK_CANCEL,
-					       GTK_RESPONSE_REJECT,
-					       NULL);
-    gtk_widget_set_size_request(GTK_WIDGET(importwindow),800,400);
   
-    g_signal_connect(G_OBJECT(importwindow), "delete_event",
-		     G_CALLBACK(delete_importwin), NULL);
-
-    vbox = GTK_WIDGET(GTK_DIALOG(importwindow)->vbox);
-
     notebook = gtk_notebook_new ();
     gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
-    gtk_box_pack_start (GTK_BOX(vbox), notebook, TRUE, TRUE, 0);
-    gtk_widget_show (notebook);
 
+#if MAEMO_VERSION_MAJOR == 5
+    scrollwin = hildon_pannable_area_new();
+    g_object_set(G_OBJECT(scrollwin), "mov-mode", HILDON_MOVEMENT_MODE_BOTH, NULL);
+#else
     scrollwin = gtk_scrolled_window_new(NULL, NULL);
+#endif
+    gtk_widget_set_size_request(scrollwin, -1, DIALOG_MIN_HEIGHT1);
 
     csvview = create_csvpreview_view (&plist, rows, cols);
     gtk_container_add (GTK_CONTAINER (scrollwin), csvview);
@@ -339,13 +396,21 @@ void callback_import( GtkAction * action, AppUIData *pui )
     label = gtk_label_new (_("Preview"));
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), scrollwin, label);
 
+#if MAEMO_VERSION_MAJOR == 5
+    colscrollwin = hildon_pannable_area_new();
+#else
     colscrollwin = gtk_scrolled_window_new(NULL, NULL);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(colscrollwin), 
 				   GTK_POLICY_NEVER, 
 				   GTK_POLICY_AUTOMATIC);
+#endif
 
     table = gtk_table_new(11, 2, FALSE);
+#if MAEMO_VERSION_MAJOR == 5
+    hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(colscrollwin),table);
+#else
     gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(colscrollwin),table);
+#endif
 
     /* Header, left column */
     label = gtk_label_new(_("Column:"));
@@ -423,9 +488,13 @@ void callback_import( GtkAction * action, AppUIData *pui )
       gtk_widget_show (pui->colspin[i]);
     }
 
+#if MAEMO_VERSION_MAJOR == 5
+    pui->dateformatentry = hildon_entry_new(HILDON_SIZE_FINGER_HEIGHT);
+#else
     pui->dateformatentry = gtk_entry_new(); 
-    gtk_entry_set_max_length(GTK_ENTRY(pui->dateformatentry), DATEFORMATENTRYMAX);
+#endif
     gtk_entry_set_text(GTK_ENTRY(pui->dateformatentry),"%Y-%m-%d");
+    gtk_entry_set_max_length(GTK_ENTRY(pui->dateformatentry), DATEFORMATENTRYMAX);
     gtk_table_attach_defaults(GTK_TABLE(table), pui->dateformatentry, 1, 2, 10, 11);
     gtk_widget_show (pui->dateformatentry);
 
@@ -436,40 +505,67 @@ void callback_import( GtkAction * action, AppUIData *pui )
 /*       gtk_widget_show (pui->colspin[i+5]); */
 /*     } */
 
-    gtk_widget_show (table);
-    gtk_widget_show(colscrollwin);
-/*     gtk_widget_show(frame); */
-
     label = gtk_label_new (_("Column designation"));
 /*     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), frame, label); */
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), colscrollwin, label);
 
   /*----------------------------------------------------------------*/
 
+#if MAEMO_VERSION_MAJOR == 5
+    carscrollwin = hildon_pannable_area_new();
+#else
     carscrollwin = gtk_scrolled_window_new(NULL, NULL);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(carscrollwin), 
 				   GTK_POLICY_NEVER, 
 				   GTK_POLICY_AUTOMATIC);
+#endif
 
     table = gtk_table_new(5, 2, FALSE);
+#if MAEMO_VERSION_MAJOR == 5
+    hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(carscrollwin),table);
+#else
     gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(carscrollwin),table);
+#endif
 
+#if MAEMO_VERSION_MAJOR == 5
+    button = hildon_picker_button_new (HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+    hildon_button_set_title (HILDON_BUTTON (button), _("Driver"));    
+    gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 2, 0, 1);
+    gtk_widget_show (button);
+    combo = create_driver_combo(pui, button);
+#else
     label = gtk_label_new(_("Driver:"));
     gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
     gtk_widget_show (label);
 
-    combo = create_driver_combo();
+    combo = create_driver_combo(pui);
     gtk_table_attach_defaults(GTK_TABLE(table), combo, 1, 2, 0, 1);
     gtk_widget_show (combo);
+#endif
 
+#if MAEMO_VERSION_MAJOR == 5
+    button = hildon_picker_button_new (HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+    hildon_button_set_title (HILDON_BUTTON (button), _("Car"));    
+    gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 2, 1, 2);
+    gtk_widget_show (button);
+    combo = create_car_combo(pui, button);
+#else
     label = gtk_label_new(_("Car:"));
     gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 1, 2);
     gtk_widget_show (label);
 
-    combo = create_car_combo();
+    combo = create_car_combo(pui);
     gtk_table_attach_defaults(GTK_TABLE(table), combo, 1, 2, 1, 2);
     gtk_widget_show (combo);
+#endif
 
+#if MAEMO_VERSION_MAJOR == 5
+    button = hildon_picker_button_new (HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+    hildon_button_set_title (HILDON_BUTTON (button), _("Units"));
+    gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 2, 2, 3);
+    gtk_widget_show (button);
+    combo = create_unit_combo(UNITCOMBO, pui, button);
+#else
     label = gtk_label_new(_("Unit:"));
     gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 2, 3);
     gtk_widget_show (label);
@@ -477,50 +573,53 @@ void callback_import( GtkAction * action, AppUIData *pui )
     combo = create_unit_combo(UNITCOMBO, pui);
     gtk_table_attach_defaults(GTK_TABLE(table), combo, 1, 2, 2, 3);
     gtk_widget_show (combo);
+#endif
 
     label = gtk_label_new(_("Start from line:"));
     gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 3, 4);
     gtk_widget_show (label);
 
-    pui->flspinner = create_column_spinner(1,100);
+    pui->flspinner = create_column_spinner(firstrow,100);
     gtk_table_attach_defaults(GTK_TABLE(table), pui->flspinner, 1, 2, 3, 4);
     gtk_widget_show (pui->flspinner);
 
+#if MAEMO_VERSION_MAJOR == 5
+    button = hildon_picker_button_new (HILDON_SIZE_AUTO, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+    hildon_button_set_title (HILDON_BUTTON (button), _("Import file locale"));
+    gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 2, 4, 5);
+    gtk_widget_show (button);
+    pui->localecombo = create_locale_combo(button);
+#else
     label = gtk_label_new(_("Import file locale:"));
     gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 4, 5);
     gtk_widget_show (label);
 
-    pui->localecombo = gtk_combo_box_new_text();
-    gtk_combo_box_append_text(GTK_COMBO_BOX (pui->localecombo),_("current"));
-    gtk_combo_box_append_text(GTK_COMBO_BOX (pui->localecombo),"C");
-    gtk_combo_box_set_active(GTK_COMBO_BOX (pui->localecombo),0);
+    pui->localecombo = create_locale_combo();
     gtk_table_attach_defaults(GTK_TABLE(table), pui->localecombo, 1, 2, 4, 5);
     gtk_widget_show (pui->localecombo);
+#endif
 
-#if PLAINGTK == 0
+    label = gtk_label_new (_("Driver/car/units"));
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), carscrollwin, label);
+
+    importwindow = hildon_wizard_dialog_new(NULL,
+					    _("Import"),
+					    GTK_NOTEBOOK(notebook));
+    gtk_widget_set_size_request(importwindow, -1, DIALOG_MIN_HEIGHTMAX);
+
+#if MAEMO_VERSION_MAJOR == 5
+    hildon_wizard_dialog_set_forward_page_func(importwindow, NULL, NULL, NULL);
+#endif
+
+#if LIBHELP == 1
     help_dialog_help_enable(GTK_DIALOG(importwindow),
 				   HELP_ID_DATABASE,
 				   pui->app->osso);
 #endif
 
-
-/*     g_signal_connect_swapped (importwindow, "response", */
-/* 			      G_CALLBACK (callback_startimport), */
-/* 			      importwindow); */
-    g_signal_connect (importwindow, "response",
-		      G_CALLBACK (callback_startimport),
-		      pui);
-
-    gtk_widget_show(table);
-    gtk_widget_show(carscrollwin);
-/*     gtk_widget_show(frame); */
-
-    label = gtk_label_new (_("Driver/car/units"));
-    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), carscrollwin, label);
-
-    gtk_widget_show(vbox);
-
     gtk_widget_show_all(GTK_WIDGET(importwindow));
+    confirm = gtk_dialog_run(GTK_DIALOG(importwindow));
+    callback_startimport(GTK_DIALOG(importwindow),confirm,pui);
   }
 
 }
@@ -529,6 +628,7 @@ void callback_export( GtkAction * action, gpointer data )
 {
   double fill;
   double trip;
+  double consum;
   char *nickname;
   gchar *filename = NULL;
   filename = interface_file_chooser ("Save file",
@@ -590,19 +690,20 @@ void callback_export( GtkAction * action, gpointer data )
 
 	      trip=sqlite3_column_double(ppStmtExport,2);
 	      fill=sqlite3_column_double(ppStmtExport,3);
+	      consum=sqlite3_column_double(ppStmtExport,4);
 
 	      fprintf(f,"\"%s\",\"%.2f\",\"%.2f\",\"%.2f\",\"%.2f\",\"%.2f\",\"%.3f\",\"%.2f\",\"%.2f\",\"%.2f\",\"%.0f\",\"%s\",\"%s\"\n",
 		      sqlite3_column_text(ppStmtExport,0),
 		      SIlength2user(sqlite3_column_double(ppStmtExport,1)),
 		      SIlength2user(trip),
 		      SIvolume2user(fill),
-		      SIconsumption2user(sqlite3_column_double(ppStmtExport,4)),
+		      SIconsumption2user(consum),
 		      sqlite3_column_double(ppStmtExport,5),
 		      SIppl2user(sqlite3_column_double(ppStmtExport,6)),
 		      sqlite3_column_double(ppStmtExport,7),
 		      sqlite3_column_double(ppStmtExport,8),
 		      sqlite3_column_double(ppStmtExport,9),
-		      SIemission2user(calc_co2_emission(fill,trip,currentcar)),
+		      SIemission2user(calc_co2_emission(consum,currentcar)),
 		      sqlite3_column_text(ppStmtExport,10),
 		      nickname
 		      );
