@@ -121,9 +121,9 @@ plot_monthly_data(AppUIData *pui, enum analysis method)
   static double *bin=NULL;
   int *year;
   int *numfills;
-  float *minconsum;
-  float *avgconsum;
-  float *maxconsum;
+  double *minconsum;
+  double *avgconsum;
+  double *maxconsum;
   int numyears;
 
 
@@ -228,8 +228,11 @@ plot_monthly_data(AppUIData *pui, enum analysis method)
       binstart=minconsum[i];
       binend=maxconsum[i];
       numbins=(int)((binend-binstart)/0.5);
-      if (numbins==0)
+      if (numbins==0) {
 	numbins=1;
+	binstart=0.9*minconsum[i]; // This is a workaround
+	binend=1.1*minconsum[i];   // to get just one fill
+      }
     }
 
     free(year);
@@ -246,21 +249,30 @@ plot_monthly_data(AppUIData *pui, enum analysis method)
     bindelta=(binend-binstart)/numbins;
     px2=(double *)malloc(numbins*sizeof(double));
     bin=(double *)malloc(numbins*sizeof(double));
-    for (i=0, binc=binstart;i<numbins;i++,binc+=bindelta) {
+    px2[0]=0.9*binstart;       // workaround to take possible 
+/*     px2[numbins-1]=1.1*binend; // rounding into account */
+    for (i=1, binc=binstart+bindelta;i<numbins;i++,binc+=bindelta) {
       px2[i]=binc;
+    }
+    for (i=0, binc=binstart;i<numbins;i++,binc+=bindelta) {
+/*       px2[i]=binc; */
       if (curunit.consumeunit==SI)
-	bin[i]=(double)db_get_consum_bin(currentyear, binc, binc+bindelta);
+/* 	bin[i]=(double)db_get_consum_bin(currentyear, binc, binc+bindelta); */
+	bin[i]=(double)db_get_consum_bin(currentyear, px2[i], binc+bindelta);
       else
-	bin[i]=(double)db_get_consum_bin(currentyear, user2SIconsumption(binc+bindelta), user2SIconsumption(binc));
+/* 	bin[i]=(double)db_get_consum_bin(currentyear, user2SIconsumption(binc+bindelta), user2SIconsumption(binc)); */
+	bin[i]=(double)db_get_consum_bin(currentyear, user2SIconsumption(px2[i]+bindelta), user2SIconsumption(binc));
       if (bin[i] > ymax) ymax=bin[i];
     }
 
     /* Bars are centered on the start of the bin, correct this */
-    offset=(px2[numbins-1]-px2[0])/(numbins-1)/2;
+    if (numbins>1)
+      offset=(px2[numbins-1]-px2[0])/(numbins-1)/2;
+    else
+      offset=SIconsumption2user(0.5);
     for (i=0; i<numbins; i++) {
       px2[i]+=offset;
     }
-    
     yval=bin;
     gtk_plot_data_set_points(dataset, px2, yval, NULL, NULL, numbins);
     break;
@@ -329,7 +341,8 @@ plot_monthly_data(AppUIData *pui, enum analysis method)
     else {
       gtk_plot_bar_set_width(GTK_PLOT_BAR(dataset), SIconsumption2user(0.5));
     }
-    gtk_plot_set_xrange(GTK_PLOT(pui->active_plot), binstart-bindelta/2.0, binend+bindelta/2.0);
+    if (binstart!=binend)
+      gtk_plot_set_xrange(GTK_PLOT(pui->active_plot), binstart-bindelta/2.0, binend+bindelta/2.0);
     gtk_plot_axis_use_custom_tick_labels(gtk_plot_get_axis(GTK_PLOT(pui->active_plot), GTK_PLOT_AXIS_BOTTOM), FALSE);
     break;
   }
